@@ -26,8 +26,9 @@ from time import sleep
 from typing import Iterable, Optional, cast
 
 import daiquiri
-import gitlab
 import typer
+
+import gitlab
 from gitlab.const import Visibility
 from gitlab.v4.objects import DeployKey, Project, ProjectCommit, ProjectKey, ProjectPipelineSchedule, User
 from gitlab.v4.objects.variables import ProjectVariable
@@ -320,7 +321,7 @@ def setup_pipeline_variables(
 
 
 def write_fetcher_project_files(
-    fetcher_project: Project, pipeline_v5_config: PipelineV5Config, *, ignore_managed_files: list[str] = None
+    fetcher_project: Project, pipeline_v5_config: PipelineV5Config, *, ignore_managed_files: list[str] | None = None
 ):
     """Write fetcher project files defined in pipeline configuration.
 
@@ -489,11 +490,8 @@ def setup_pipeline_schedules(project: Project, fetcher_def: FetcherDef, ctx: Con
 
     Schedules that are not mentioned in fetcher definition are deleted.
     """
-    logger.debug("Configuring pipeline schedules for project %r...", project.path_with_namespace)
 
-    schedule_defs = fetcher_def.schedules.copy()
-
-    for schedule in cast(Iterable[ProjectPipelineSchedule], project.pipelineschedules.list(as_list=False)):
+    def process_schedule(schedule: ProjectPipelineSchedule):
         schedule_def_index = find_index(
             lambda schedule_def: schedule_def.cron == schedule.cron and schedule_def.timezone == schedule.cron_timezone,
             schedule_defs,
@@ -510,6 +508,13 @@ def setup_pipeline_schedules(project: Project, fetcher_def: FetcherDef, ctx: Con
                 )
                 take_ownership(schedule, schedule_def.owner, ctx)
 
+    logger.debug("Configuring pipeline schedules for project %r...", project.path_with_namespace)
+
+    schedule_defs = fetcher_def.schedules.copy()
+
+    for schedule in cast(Iterable[ProjectPipelineSchedule], project.pipelineschedules.list(as_list=False)):
+        process_schedule(schedule)
+
     for schedule_def in schedule_defs:
         logger.info("Creating schedule from %r...", schedule_def)
         create_pipeline_schedule(project, schedule_def, ctx)
@@ -560,7 +565,7 @@ def fork_project(upstream_project: Project, group_name: str, project_name: str,
     commits: list[ProjectCommit] = []
     while True:
         try:
-            commits = project.commits.list(per_page=1)
+            commits = cast(list[ProjectCommit], project.commits.list(per_page=1))
         except gitlab.exceptions.GitlabListError:
             # GitLab can return a 500 error when fetching commits while forking.
             pass
